@@ -16,7 +16,6 @@
 # under the License.
 from __future__ import annotations
 
-from copy import deepcopy
 from datetime import datetime, timedelta
 from unittest.mock import MagicMock, patch
 
@@ -25,15 +24,14 @@ import time_machine
 
 from airflow.configuration import conf
 from airflow.models.taskinstancekey import TaskInstanceKey
+from airflow.providers.common.compat.sdk import Stats, timezone
 from airflow.providers.edge3.executors.edge_executor import EdgeExecutor
 from airflow.providers.edge3.models.edge_job import EdgeJobModel
 from airflow.providers.edge3.models.edge_worker import EdgeWorkerModel, EdgeWorkerState
-from airflow.utils import timezone
 from airflow.utils.session import create_session
 from airflow.utils.state import TaskInstanceState
 
 from tests_common.test_utils.config import conf_vars
-from tests_common.test_utils.version_compat import AIRFLOW_V_3_0_PLUS
 
 pytestmark = pytest.mark.db_test
 
@@ -58,43 +56,12 @@ class TestEdgeExecutor:
 
         return (executor, key)
 
-    @pytest.mark.skipif(AIRFLOW_V_3_0_PLUS, reason="_process_tasks is not used in Airflow 3.0+")
-    def test__process_tasks_bad_command(self):
-        executor, key = self.get_test_executor()
-        task_tuple = (key, ["hello", "world"], None, None)
-        with pytest.raises(ValueError):
-            executor._process_tasks([task_tuple])
-
-    @pytest.mark.skipif(AIRFLOW_V_3_0_PLUS, reason="_process_tasks is not used in Airflow 3.0+")
-    @pytest.mark.parametrize(
-        "pool_slots, expected_concurrency",
-        [
-            pytest.param(1, 1, id="default_pool_size"),
-            pytest.param(5, 5, id="increased_pool_size"),
-        ],
-    )
-    def test__process_tasks_ok_command(self, pool_slots, expected_concurrency):
-        executor, key = self.get_test_executor(pool_slots=pool_slots)
-        task_tuple = (key, ["airflow", "tasks", "run", "hello", "world"], None, None)
-        executor._process_tasks([task_tuple])
-
-        with create_session() as session:
-            jobs: list[EdgeJobModel] = session.query(EdgeJobModel).all()
-        assert len(jobs) == 1
-        assert jobs[0].dag_id == "test_dag"
-        assert jobs[0].run_id == "test_run"
-        assert jobs[0].task_id == "test_task"
-        assert jobs[0].concurrency_slots == expected_concurrency
-
-    @patch("airflow.stats.Stats.incr")
+    @patch(f"{Stats.__module__}.Stats.incr")
     def test_sync_orphaned_tasks(self, mock_stats_incr):
         executor = EdgeExecutor()
 
         delta_to_purge = timedelta(minutes=conf.getint("edge", "job_fail_purge") + 1)
-        if AIRFLOW_V_3_0_PLUS:
-            delta_to_orphaned_config_name = "task_instance_heartbeat_timeout"
-        else:
-            delta_to_orphaned_config_name = "scheduler_zombie_task_threshold"
+        delta_to_orphaned_config_name = "task_instance_heartbeat_timeout"
 
         delta_to_orphaned = timedelta(seconds=conf.getint("scheduler", delta_to_orphaned_config_name) + 1)
 
@@ -247,6 +214,11 @@ class TestEdgeExecutor:
 
         # Prepare some data
         with create_session() as session:
+            # Clear existing workers to avoid unique constraint violation
+            session.query(EdgeWorkerModel).delete()
+            session.commit()
+
+            # Add workers with different states
             for worker_name, state, last_heartbeat in [
                 (
                     "inactive_timed_out_worker",
@@ -292,49 +264,85 @@ class TestEdgeExecutor:
                 else:
                     assert worker.state == EdgeWorkerState.IDLE
 
-    @pytest.mark.skipif(AIRFLOW_V_3_0_PLUS, reason="API only available in Airflow <3.0")
-    def test_execute_async(self):
-        executor, key = self.get_test_executor()
-
-        # Need to apply "trick" which is used to pass pool_slots
-        executor.edge_queued_tasks = deepcopy(executor.queued_tasks)
-
-        executor.execute_async(key=key, command=["airflow", "tasks", "run", "hello", "world"])
-
-        with create_session() as session:
-            jobs = session.query(EdgeJobModel).all()
-            assert len(jobs) == 1
-
-    @pytest.mark.skipif(not AIRFLOW_V_3_0_PLUS, reason="API only available in Airflow 3.0+")
-    def test_queue_workload(self):
-        from airflow.executors.workloads import ExecuteTask, TaskInstance
-
-        executor = self.get_test_executor()[0]
-
-        with pytest.raises(TypeError):
-            # Does not like the Airflow 2.10 type of workload
-            executor.queue_workload(command=["airflow", "tasks", "run", "hello", "world"])
-
-        workload = ExecuteTask(
-            token="mock",
-            ti=TaskInstance(
-                id="4d828a62-a417-4936-a7a6-2b3fabacecab",
-                task_id="mock",
-                dag_id="mock",
-                run_id="mock",
-                try_number=1,
-                pool_slots=1,
-                queue="default",
-                priority_weight=1,
-                start_date=timezone.utcnow(),
-                dag_version_id="4d828a62-a417-4936-a7a6-2b3fabacecab",
-            ),
-            dag_rel_path="mock.py",
-            log_path="mock.log",
-            bundle_info={"name": "n/a", "version": "no matter"},
+    def test_revoke_task(self):
+        """Test that revoke_task removes task from executor and database."""
+        executor = EdgeExecutor()
+        key = TaskInstanceKey(
+            dag_id="test_dag", run_id="test_run", task_id="test_task", map_index=-1, try_number=1
         )
-        executor.queue_workload(workload=workload)
 
+        # Create a mock task instance
+        ti = MagicMock()
+        ti.key = key
+        ti.dag_id = "test_dag"
+        ti.task_id = "test_task"
+        ti.run_id = "test_run"
+        ti.map_index = -1
+        ti.try_number = 1
+
+        # Add task to executor's internal state
+        executor.running.add(key)
+        executor.queued_tasks[key] = [None, None, None, ti]
+        executor.last_reported_state[key] = TaskInstanceState.QUEUED
+
+        # Add corresponding job to database
+        with create_session() as session:
+            session.add(
+                EdgeJobModel(
+                    dag_id="test_dag",
+                    task_id="test_task",
+                    run_id="test_run",
+                    map_index=-1,
+                    try_number=1,
+                    state=TaskInstanceState.QUEUED,
+                    queue="default",
+                    command="mock",
+                    concurrency_slots=1,
+                )
+            )
+            session.commit()
+
+        # Verify job exists before revoke
         with create_session() as session:
             jobs = session.query(EdgeJobModel).all()
             assert len(jobs) == 1
+
+        # Revoke the task
+        executor.revoke_task(ti=ti)
+
+        # Verify task is removed from executor's internal state
+        assert key not in executor.running
+        assert key not in executor.queued_tasks
+        assert key not in executor.last_reported_state
+
+        # Verify job is removed from database
+        with create_session() as session:
+            jobs = session.query(EdgeJobModel).all()
+            assert len(jobs) == 0
+
+    def test_revoke_task_nonexistent(self):
+        """Test that revoke_task handles non-existent tasks gracefully."""
+        executor = EdgeExecutor()
+        key = TaskInstanceKey(
+            dag_id="nonexistent_dag",
+            run_id="nonexistent_run",
+            task_id="nonexistent_task",
+            map_index=-1,
+            try_number=1,
+        )
+
+        # Create a mock task instance
+        ti = MagicMock()
+        ti.key = key
+        ti.dag_id = "nonexistent_dag"
+        ti.task_id = "nonexistent_task"
+        ti.run_id = "nonexistent_run"
+        ti.map_index = -1
+        ti.try_number = 1
+
+        # Revoke a task that doesn't exist (should not raise error)
+        executor.revoke_task(ti=ti)
+
+        # Verify nothing breaks
+        assert key not in executor.running
+        assert key not in executor.queued_tasks
